window.onload = function () {
    var isSaving = false;
    var titlePattern = /^[a-zA-Z0-9\u4E00-\u9FA5\s\^\-_*&`~\\/|;；:：{},!@#$&().'\&quot;\[\]<>?·！（）——、‘“”？—。，《》%【】\\+]+$/;
    var vm = new Vue({
        el: '#view-container',
        data: {
            projectInfo: {
                "projectName": "",
                "projectDes": ""
            },
            errorHintMessage: "",
            errorStatus: {
                "projectName": false,
                "projectDes": false
            },
            normal: false
        },
        watch: {
            projectInfo: {
                handler: function (val, oldVal) {
                    var subject = this.projectInfo.projectName;
                    if (subject.replace(/\s/g, "") != "") {
                        uSetSaveButtonClickable("true");
                    } else {
                        uSetSaveButtonClickable("false");
                    }
                },
                deep: true
            }
        },
        methods: {
            confirmBack: function () {
                uHideLoadingPage();
                uFinishCurrentPage();
            },
            goBack: function () {
                if (isSaving) {
                    return;
                }
                var subject = this.projectInfo.projectName;
                var des = this.projectInfo.projectDes;
                if (subject.replace(/\s/g, "") != "" || des.replace(/\s/g, "") != "") {
                    uShowConformDialog(stringMap.go_back_confirm);
                } else {
                    uHideLoadingPage();
                    uFinishCurrentPage();
                }
            },
            validate: function () {
                var newProjectName = this.projectInfo.projectName;
                var newProjectDescription = this.projectInfo.projectDes;
                this.errorStatus.projectName = false;
                this.errorStatus.projectDes = false;
                if (newProjectName == "") {
                    uShowToast(stringMap.project_name_limit1);
                    this.errorHintMessage ="项目名称不能为空";
                    this.errorStatus.projectName = true;
                } else if ((!(newProjectName.match(titlePattern)))) {
                    uShowToast(stringMap.project_name_limit2);
                    this.errorHintMessage = "项目名称输入不合法";
                    this.errorStatus.projectName = true;
                } else if (newProjectName.length < 3) {
                    uShowToast(stringMap.project_name_limit3);
                    this.errorHintMessage = "项目名称不能少于3个字符";
                    this.errorStatus.projectName = true;
                } else if (newProjectName.length > 128) {
                    uShowToast(stringMap.project_name_limit4);
                    this.errorHintMessage = "项目名称不能超过128个字符";
                    this.errorStatus.projectName = true;
                } else if (newProjectDescription.length > 1024) {
                    uShowToast(stringMap.project_description_limit1);
                    this.errorHintMessage = "项目描述不能超过1024个字符";
                    this.errorStatus.projectDes = true;
                } else if (!(newProjectDescription.match(titlePattern)) && newProjectDescription) {
                    uShowToast(stringMap.project_description_limit2);
                    this.errorHintMessage = "项目描述输入不合法";
                    this.errorStatus.projectDes = true;
                } else {
                    this.errorHintMessage = "";
                    return true;
                }
                return false;
            },
            save: function () {
                //console.log("isSaving="+isSaving);
                if (this.validate()) {
                    if (isSaving) return;
                    isSaving = true;
                    var newProjectName = this.projectInfo.projectName.replace(/(^\s*)|(\s*$)/g, "");
                    var newProjectDescription = this.projectInfo.projectDes.replace(/(^\s*)|(\s*$)/g, "");
                    var self = this;
                    uShowLoadingPage();
                    hCheckProjectUniqueness({
                        "project_name": encodeURIComponent(newProjectName)
                    }, function (data) {
                        //console.log(data);
                        var projectNameAlreadyExists = data.exist;
                        if (!projectNameAlreadyExists) {
                            hCreateProject({
                                "name": encodeURIComponent(newProjectName),
                                "description": encodeURIComponent(newProjectDescription),
                                "type":self.normal ? "normal" : "scrum"
                            }, function (responseData) {
                                uSet("needRequestProject","true");
                                // uShowToast(stringMap.project_create_success);
                                uFinishCurrentPage();
                            }, function (data) {
                                uHideLoadingPage();
                                uShowAlertDialog(data.reason);
                                isSaving = false;
                            })
                        } else {
                            uHideLoadingPage();
                            uShowToast(stringMap.project_name_duplicate);
                            self.errorHintMessage = "项目名称与已有项目重复";
                            $("#projectInsertion_name_input").addClass("public_input_error_hint");
                            isSaving = false;
                        }
                    }, function (data) {
                        uHideLoadingPage();
                        uShowAlertDialog(data.reason);
                        isSaving = false;
                    })
                }
            },
            modeSwitch: function (toNormal) {
                this.normal = toNormal;
            }
        },
        created: function () {
            var self = this;
            uSetPublicBackButtonClickListener(function (){
                self.goBack();
            });
            uSetConfirmDialogConfirmedListener(function () {
                self.confirmBack();
            });
        },
        mounted: function() {
            var self = this;
            uShowSelf();
            uSetPublicCompleteButtonClickListener(function () {
                self.save();
            });
            uSetSaveButtonClickable("false");
        }
    })
};
