window.onload = function () {
    var projectUUId = uGet("project_uuid");
    var projectImageDirectoryPath = "../../theme/image/";
    var isSaving = false;
    var projectModules = {
        all: [],
        short: []
    };
    var projectDomains = {
        all: [],
        short: []
    };
    var projectMilestones = {
        all: [],
        short: []
    };

    var vm = new Vue({
        el: '#view-container',
        data: {
            projectInfo: {
                "projectName": "",
                "projectDes": "",
                'projectImage': "",
                'watch': false,
                'projectId': 0
            },
            members: [],
            membersLength: 0,
            PROJECT_MEMBERS_SHORT_MAX_LENGTH: 3,
            modules: [],
            modulesLength: 0,
            projectModulesIsAll: false,
            PROJECT_MODULES_SHORT_MAX_LENGTH: 3,
            domains: [],
            domainsLength: 0,
            projectDomainsIsAll: false,
            PROJECT_DOMAINS_SHORT_MAX_LENGTH: 1,
            milestones: [],
            milestonesLength: 0,
            projectMilestonesIsAll: false,
            PROJECT_MILESTONES_SHORT_MAX_LENGTH: 1,
            readOnly: true,
            canDelete: false
        },
        computed: {
            projectBackgroudClass: function () {
                return "projectManagement_category_info_background" + (this.projectInfo.projectId % 3);
            }
        },
        methods: {
            goBack: function () {
                rProject();
            },
            goProjectEdition: function () {
                rProjectEdition(projectUUId);
            },
            goWorkItem: function () {
                rWorkItem(projectUUId);
            },
            goMember: function () {
                rMember(projectUUId);
            },
            goModule: function () {
                rModule(projectUUId);
            },
            goDomain: function () {
                rDomain(projectUUId);
            },
            goMilestone: function () {
                rMilestone(projectUUId);
            },
            getProjectDetails: function () {
                var self = this;
                hGetProjectDetails({
                    "project_uuid": projectUUId
                }, function (data) {
                    uShowSelf();
                    var projectInfo = data.project;
                    self.projectInfo.projectName = projectInfo.name;
                    self.projectInfo.projectDes = projectInfo.description;
                    self.projectInfo.projectImage = projectImageDirectoryPath + projectInfo.image_url;
                    self.projectInfo.projectId = projectInfo.id;
                    var role = Number(projectInfo.role);
                    uSet("currentUserRoleInProject", role);
                    if ((role == ROLE.CREATOR) || (role == ROLE.MANAGER) || (role == ROLE.TESTMANAGER)) {
                        if (role == ROLE.CREATOR) {
                            uShowDeleteButton();
                        }
                        self.readOnly = false;
                    }
                });
            },
            getMembers: function () {
                var self = this;
                hGetUserListByProjectId({
                    "project_uuid": projectUUId,
                    "page_no": 1,
                    "page_size": 20
                }, function (data) {
                    var members = [];
                    self.membersLength = data.total;
                    for (var i = 0; i < data.members.length && i < self.PROJECT_MEMBERS_SHORT_MAX_LENGTH; i++) {
                        data.members[i].photo = uGetPhotoPath(data.members[i].image);
                        members.push(data.members[i]);
                    }
                    self.members = members;
                });
            },
            getModules: function () {
                var self = this;
                hGetModule({
                    "project_uuid": projectUUId
                }, function (data) {
                    projectModules.all = data.modules;
                    if (projectModules.all.length <= self.PROJECT_MODULES_SHORT_MAX_LENGTH) {
                        self.modules = projectModules.all;
                    } else {
                        projectModules.short = [];
                        for (var i = 0; i < self.PROJECT_MODULES_SHORT_MAX_LENGTH; i++) {
                            projectModules.short.push(projectModules.all[i])
                        }
                        self.modules = projectModules.short;
                    }
                    self.modulesLength = projectModules.all.length;
                    $("#projectManagement_module").css("height", 120 * (self.modules.length > 0 ? self.modules.length : 1) + "px");
                });
            },
            getDomains: function () {
                var self = this;
                hGetDomain({
                    "project_uuid": projectUUId
                }, function (data) {
                    projectDomains.all = data.domains;
                    if (projectDomains.all.length <= self.PROJECT_DOMAINS_SHORT_MAX_LENGTH) {
                        self.domains = projectDomains.all;
                    } else {
                        projectDomains.short = [];
                        for (var i = 0; i < self.PROJECT_DOMAINS_SHORT_MAX_LENGTH; i++) {
                            projectDomains.short.push(projectDomains.all[i])
                        }
                        self.domains = projectDomains.short;
                    }
                    self.domainsLength = projectDomains.all.length;
                    $("#projectManagement_domain").css("height", 120 * (self.domains.length > 0 ? self.domains.length : 1) + "px");
                });
            },
            getMilestones: function () {
                var self = this;
                hGetMilestone({
                    "project_uuid": projectUUId
                }, function (data) {
                    projectMilestones.all = data.versions;
                    if (projectMilestones.all.length <= self.PROJECT_MILESTONES_SHORT_MAX_LENGTH) {
                        self.milestones = projectMilestones.all;
                    } else {
                        projectMilestones.short = [];
                        var nearestFutureMilestoneIndex = -1;
                        var rangeToNearestFuture = 0;
                        var nearestPastMilestoneIndex = -1;
                        var rangeToNearestPast = 0;
                        var currentDate = new Date().getTime();
                        for (var i = 0; i < projectMilestones.all.length; i++) {
                            var startDate = new Date(projectMilestones.all[i].start_date).getTime();
                            var dueDate = new Date(projectMilestones.all[i].due_date).getTime();
                            if (currentDate >= startDate && currentDate <= dueDate) {
                                projectMilestones.short.push(projectMilestones.all[i]);
                                break;
                            }
                            if (currentDate < startDate && (rangeToNearestFuture == 0 || rangeToNearestFuture > startDate - currentDate)) {
                                nearestFutureMilestoneIndex = i;
                                rangeToNearestFuture = startDate - currentDate;
                            }
                            if (currentDate > dueDate && (rangeToNearestPast == 0 || rangeToNearestPast > currentDate - dueDate)) {
                                nearestPastMilestoneIndex = i;
                                rangeToNearestPast = currentDate - dueDate;
                            }
                        }
                        if (projectMilestones.short.length == 0) {
                            if (nearestFutureMilestoneIndex != -1) {
                                projectMilestones.short.push(projectMilestones.all[nearestFutureMilestoneIndex]);
                            } else if (nearestPastMilestoneIndex != -1) {
                                projectMilestones.short.push(projectMilestones.all[nearestPastMilestoneIndex]);
                            }
                        }
                        self.milestones = projectMilestones.short;
                    }
                    self.milestonesLength = projectMilestones.all.length;
                    $("#projectManagement_milestone").css("height", 120 * (self.milestones.length > 0 ? self.milestones.length : 1) + "px");
                });
            },
            showModulesAllOrShort: function () {
                var self = this;
                self.modules = self.projectModulesIsAll ? projectModules.short : projectModules.all;
                self.projectModulesIsAll = !self.projectModulesIsAll;
                $("#projectManagement_module").css("height", 120 * self.modules.length + "px");
            },
            showDomainsAllOrShort: function () {
                var self = this;
                self.domains = self.projectDomainsIsAll ? projectDomains.short : projectDomains.all;
                self.projectDomainsIsAll = !self.projectDomainsIsAll;
                $("#projectManagement_domain").css("height", 120 * self.domains.length + "px");
            },
            showMilestonesAllOrShort: function () {
                var self = this;
                self.milestones = self.projectMilestonesIsAll ? projectMilestones.short : projectMilestones.all;
                self.projectMilestonesIsAll = !self.projectMilestonesIsAll;
                $("#projectManagement_milestone").css("height", 120 * self.milestones.length + "px");
            },
            deleteModule: function (moduleId) {
                var self = this;
                hDeleteModule({
                    "id": moduleId,
                    "project_uuid": projectUUId
                }, function (data) {
                    self.getModules();
                }, function (error) {
                    if (error.code == 'DEV_21_40037') {
                        uShowToast(stringMap.module_delete_fail);
                    }
                })
            },
            testDomainClick: function () {
            },
            deleteDomain: function (domainId) {
                var self = this;
                hDeleteDomain({
                    "domain_id": domainId,
                    "project_uuid": projectUUId
                }, function (data) {
                    self.getDomains();
                }, function (error) {
                    if (error.code == 'DEV_21_40036') {
                        uShowToast(stringMap.domain_delete_fail);
                    }
                })
            },
            deleteMilestone: function (milestoneId) {
                var self = this;
                hDeleteMilestone({
                    "version_id": milestoneId,
                    "project_uuid": projectUUId
                }, function (data) {
                    self.getMilestones();
                });
            },
            watchProjectOrNot: function (event) {
                event.stopPropagation();
                if (isSaving) return;
                isSaving = true;
                var self = this;
                if (self.projectInfo.watch) {
                    hWatchProjectCancel({
                        "project_uuid": projectUUId
                    }, function (data) {
                        self.projectInfo.watch = false;
                        isSaving = false;
                    })
                } else {
                    hWatchProject({
                        "project_uuid": projectUUId
                    }, function (data) {
                        self.projectInfo.watch = true;
                        isSaving = false;
                    })
                }
            }
        },
        filters: {
            formatDate: function (value) {
                return value.replace(/-/g, "/");
            }
        },
        created: function () {
            var self = this;
            self.getProjectDetails();
            uSetPublicBackButtonClickListener(function () {
                self.goBack();
            });
            uSetPublicDeletePositiveButtonClickListener(function () {
                if (isSaving) return;
                isSaving = true;
                hDeleteProject({
                    "project_uuid": projectUUId
                }, function (data) {
                    rProject();
                })
            });
            self.getDomains();
            self.getModules();
            self.getMilestones();
        }
    })
};
