window.onload = function () {
    var vm = new Vue({
        el: '#view-container',
        data: {
            hasSearch:false,
            items: [],
            itemList: [],
            queryValue: "",
            searchHint: [],
            isAssignerList:false,
            indexList: [],
            isKeyboardShown: false,
            isIterationList: false,
            workItemInfo:"",
            showSearchHint:false
        },

        filters: {
            formatDate: function (time) {
                var t = new Date(time);
                var tf = function (i) {
                    return (i < 10 ? '0' : '') + i
                };
                return 'yyyy-MM-dd'.replace(/yyyy|MM|dd|HH|mm|ss/g, function (a) {
                    switch (a) {
                        case 'yyyy':
                            return tf(t.getFullYear());
                            break;
                        case 'MM':
                            return tf(t.getMonth() + 1);
                            break;
                        case 'mm':
                            return tf(t.getMinutes());
                            break;
                        case 'dd':
                            return tf(t.getDate());
                            break;
                        case 'HH':
                            return tf(t.getHours());
                            break;
                        case 'ss':
                            return tf(t.getSeconds());
                            break;
                    }
                })
            }
        },

        mounted: function () {
            var self = this;
            uSetPublicBackButtonClickListener(function () {
                self.goBack();
            });
            self.hasSearch = (uGet("hasSearch") == "true") ? true : false;
            self.isAssignerList = ((uGet("web_view_fragment_title") == "选择处理人")) ? true : false;
            self.isIterationList = ((uGet("web_view_fragment_title") == "选择迭代")) ? true : false;
            self.workItemInfo = JSON.parse(uGet("workItemInfo"));

            switch (uGet("web_view_fragment_title")) {
                case '选择处理人':
                    this.getUserList();
                    break;
                case '选择项目':
                    this.getProjectList();
                    break;
                case '选择重要程度':
                    this.getSeverityList();
                    break;
                case '选择状态':
                    this.getStatusList();
                    break;
                case '选择迭代':
                    this.getIterationList();
                    break;
                case '选择模块':
                    this.getModuleList();
                    break;
                case '选择领域':
                    this.getDomainList();
                    break;
                case '选择类型':
                case '选择优先级':
                    self.itemList = JSON.parse(uGet("itemList"));
                    self.items = self.itemList;
                    break;
            }

            if (self.hasSearch) {
                self.searchHint = JSON.parse(uGet("searchHint"));
            }
            if ((uGet("web_view_fragment_title") == "选择领域")) {
                self.searchHint = JSON.parse(uGet("searchHint"));
            }
            this.$nextTick(function () {
                uShowSelf();
            });

            uSetKeyboardHeightListener(function (height) {
                console.log("workItemList:keyboard height:" + height);
                self.isKeyboardShown = height == "0" ? false: true;
            });
        },

        methods: {
            getUserList: function () {
                var userList;
                var self = this;
                if (uGet("userList") && uGet("userList") != "") {
                    userList = JSON.parse(uGet("userList"));
                    self.setUserList(userList);
                    self.itemList = userList;
                    self.items = self.itemList;
                } else {
                    uShowLoadingPage();
                    hGetUserListByProjectId({
                        "project_uuid": self.workItemInfo.project.uuid
                    }, function (data) {
                        userList = data.members;
                        uSet("userList",JSON.stringify(userList));
                        self.setUserList(userList);
                        self.itemList = userList;
                        self.items = self.itemList;
                        self.showSearchHint = true;
                        uHideLoadingPage();

                        self.$nextTick(function () {
                            if ($("#workItem_memberList")[0].scrollHeight > window.innerHeight) {
                                $("#workItem_memberList")[0].style.height = window.innerHeight - 100 + "px";
                            }

                            for (var i = 0; i < self.items.length; i++) {
                                if (self.items[i].group_name == '#') {
                                    self.items[i].top = $("#number_sign").offset().top;
                                } else {
                                    self.items[i].top = $("#" + self.items[i].group_name).offset().top;
                                }
                                console.log("self.items[i].top:" + self.items[i].top);
                            }
                            self.indexList = ["#", "A","B","C","D","E","F","G","H","I","J","K","L","M","N","O","P","Q","R","S","T","U","V","W","X","Y","Z"];
                        });


                    });
                }
            },
            setUserList: function (userList) {
                var self = this;
                var tmpAssigner = null;
                var checkedI = -1;
                var checkedJ = -1;
                for (var i = 0; i < userList.length; i++) {
                    for (var j = 0; j < userList[i].group_members.length; j++) {
                        userList[i].group_members[j].checked = false;
                        userList[i].group_members[j].sid = j;
                    }

                    for (var j = 0; j < userList[i].group_members.length; j++) {
                        if (userList[i].group_members[j].id == self.workItemInfo.assigner.id) {
                            tmpAssigner = userList[i].group_members[j];
                            checkedI = i;
                            checkedJ = j;
                            break;
                        }
                    }
                }
                if (tmpAssigner != null) {
                    userList[checkedI].group_members[checkedJ].checked = true;
                }
            },
            getDomainList: function () {
                var domainList;
                var self = this;
                if (uGet("domainList") && uGet("domainList") != "") {
                    domainList = JSON.parse(uGet("domainList"));
                    self.setList(domainList, self.workItemInfo.domain.id ? self.workItemInfo.domain.id : -1);
                    self.itemList = domainList;
                    self.items = self.itemList;
                } else {
                    uShowLoadingPage();
                    hGetDomain({
                        "project_uuid": self.workItemInfo.project.uuid
                    }, function (data) {
                        domainList = [];
                        if (data.domains.length > 0) {
                            domainList[0] = {'name': '待分配', 'checked': true, 'sid': 0, 'id':-1};
                            var tmpDomainList = data.domains;
                            for (var i = 0; i < tmpDomainList.length; i++) {
                                tmpDomainList[i].sid = i + 1;
                                domainList.push(tmpDomainList[i]);
                            }
                            uSet("domainList",JSON.stringify(domainList));
                            self.setList(domainList, self.workItemInfo.domain.id ? self.workItemInfo.domain.id : -1);
                            self.itemList = domainList;
                            self.items = self.itemList;
                            self.showSearchHint = true;
                            uHideLoadingPage();
                        } else {
                            self.itemList = domainList;
                            self.items = self.itemList;
                            self.showSearchHint = true;
                            uHideLoadingPage();
                        }
                    });
                }
            },
            getModuleList: function () {
                var moduleList;
                var self = this;
                if (uGet("moduleList") && uGet("moduleList") != "") {
                    moduleList = JSON.parse(uGet("moduleList"));
                    self.setList(moduleList, self.workItemInfo.module.id ? self.workItemInfo.module.id : -1);
                    self.itemList = moduleList;
                    self.items = self.itemList;
                } else {
                    uShowLoadingPage();
                    hGetModule({
                        "project_uuid": self.workItemInfo.project.uuid
                    }, function (data) {
                        moduleList = [];
                        if (data.modules.length > 0) {
                            moduleList[0] = {'name': '待分配', 'checked': true, 'sid': 0, 'id':-1};
                            var tmpModuleList = data.modules;
                            for (var i = 0; i < tmpModuleList.length; i++) {
                                tmpModuleList[i].sid = i + 1;
                                moduleList.push(tmpModuleList[i]);
                            }
                            uSet("moduleList",JSON.stringify(moduleList));
                            self.setList(moduleList, self.workItemInfo.module.id ? self.workItemInfo.module.id : -1);
                            self.itemList = moduleList;
                            self.items = self.itemList;
                            if (uGet("userList") && uGet("userList") != "") {
                                self.searchHint = true;
                                uHideLoadingPage();
                            } else {
                                hGetUserListByProjectId({
                                    "project_uuid": self.workItemInfo.project.uuid
                                }, function (data) {
                                    uSet("userList",JSON.stringify(data.members));
                                    self.showSearchHint = true;
                                    uHideLoadingPage();
                                });
                            }
                        } else {
                            self.itemList = moduleList;
                            self.items = self.itemList;
                            self.showSearchHint = true;
                            uHideLoadingPage();
                        }
                    });
                }
            },
            getIterationList: function () {
                var iterationList;
                var self = this;
                if (uGet("iterationList") && uGet("iterationList") != "") {
                    iterationList = JSON.parse(uGet("iterationList"));
                    self.setList(iterationList, self.workItemInfo.iteration.id ? self.workItemInfo.iteration.id : -1);
                    self.itemList = iterationList;
                    self.items = self.itemList;
                } else {
                    uShowLoadingPage();
                    hGetMilestone({
                        "project_uuid": self.workItemInfo.project.uuid
                    }, function (data) {
                        iterationList = [];
                        if (data.iterations.length > 0) {
                            iterationList[0] = {'name': '待分配', 'checked': true, 'sid': 0, 'id':-1};
                            var tmpIterationList = data.iterations;
                            for (var i = 0; i < tmpIterationList.length; i++) {
                                tmpIterationList[i].sid = i + 1;
                                iterationList.push(tmpIterationList[i]);
                            }
                            uSet("iterationList",JSON.stringify(iterationList));
                            self.setList(iterationList,self.workItemInfo.iteration.id ? self.workItemInfo.iteration.id : -1);
                            self.itemList = iterationList;
                            self.items = self.itemList;
                            self.showSearchHint = true;
                            uHideLoadingPage();
                        } else {
                            self.itemList = iterationList;
                            self.items = self.itemList;
                            self.showSearchHint = true;
                            uHideLoadingPage();
                        }
                    });
                }
            },
            getProjectList: function () {
                var projectList;
                var self = this;
                if (uGet("projectList") && uGet("projectList") != "") {
                    projectList = JSON.parse(uGet("projectList"));
                    self.setList(projectList, self.workItemInfo.project.id);
                    self.itemList = projectList;
                    self.items = self.itemList;
                } else {
                    uShowLoadingPage();
                    hGetMyProjects({
                        "type": "normal",
                        "query_type": "simplify"
                    }, function (data) {
                        projectList = data.projects;
                        uSet("projectList",JSON.stringify(projectList));
                        self.setList(projectList, self.workItemInfo.project.id);
                        self.itemList = projectList;
                        self.items = self.itemList;
                        self.showSearchHint = true;
                        uHideLoadingPage();
                    });
                }
            },
            getStatusList: function () {
                var statusList;
                var self = this;
                if (uGet("statusList") && uGet("statusList") != "") {
                    statusList = JSON.parse(uGet("statusList"));
                    self.setList(statusList, self.workItemInfo.status.id);
                    self.itemList = statusList;
                    self.items = self.itemList;
                } else {
                    uShowLoadingPage();
                    hGetStatus({
                        "project_uuid": self.workItemInfo.project.uuid
                    }, function (data) {
                        statusList = data.statuses;
                        uSet("statusList",JSON.stringify(statusList));
                        console.log(uGet("workItemInfo"));
                        self.setList(statusList, self.workItemInfo.status.id);
                        self.itemList = statusList;
                        self.items = self.itemList;
                        self.showSearchHint = true;
                        uHideLoadingPage();
                    });
                }
            },
            getSeverityList: function () {
                var severityList;
                var self = this;
                if (uGet("severityList") && uGet("severityList") != "") {
                    severityList = JSON.parse(uGet("severityList"));
                    self.setList(severityList, self.workItemInfo.severity.id);
                    self.itemList = severityList;
                    self.items = self.itemList;
                } else {
                    uShowLoadingPage();
                    hGetSeverity({}, function (data) {
                        severityList = data.severities;
                        uSet("severityList",JSON.stringify(severityList));
                        console.log(uGet("workItemInfo"));
                        self.setList(severityList, self.workItemInfo.severity.id);
                        self.itemList = severityList;
                        self.items = self.itemList;
                        self.showSearchHint = true;
                        uHideLoadingPage();
                    });
                }
            },
            setList: function (list, id) {
                for (var i = 0; i < list.length; i++) {
                    list[i].checked = false;
                    list[i].sid = i;
                    if (list[i].id == id) {
                        list[i].checked = true;
                    }
                    if (list[i].project_uuid == id) {
                        list[i].checked = true;
                    }
                    if (list[i].statusId == id) {
                        list[i].checked = true;
                    }
                }
            },
            scrollToIndex: function (index) {
                console.log("scrollToIndex:" + index);
                for (var i = 0; i < this.items.length; i++) {
                    if (this.items[i].group_name.toUpperCase() == index) {
                        var div = $("#workItem_memberList")[0];
                        div.scrollTop = this.items[i].top - 100;
                        console.log("div.scrollTop:" + div.scrollTop);
                    }
                }
            },
            goBack: function () {
                uFinishCurrentPage();
            },

            chooseItemFromList: function (item,itemGroup) {
                item.checked = true;
                uSet("choosedItem",JSON.stringify(item));
                uSet("choosedItemGroup",JSON.stringify(itemGroup));
                uFinishCurrentPage();
            },

            search: function () {
                if (this.queryValue != "") {
                    if (!this.isAssignerList) {
                        this.items = [];
                        for (var i = 0; i < this.itemList.length; i++) {
                            if (this.itemList[i].name.indexOf(this.queryValue) >= 0) {
                                this.items.push(this.itemList[i]);
                            }
                        }
                    } else {
                        this.items = [];

                        for (var i = 0; i < this.itemList.length; i++) {
                            var tmpGroups = {
                                "group_name":this.itemList[i].group_name,
                                "group_members":[]
                            };
                            for (var j = 0; j < this.itemList[i].group_members.length; j++) {
                                if (this.itemList[i].group_members[j].name.indexOf(this.queryValue) >= 0 || (this.itemList[i].group_members[j].remark_name && this.itemList[i].group_members[j].remark_name.indexOf(this.queryValue) >= 0) || (this.itemList[i].group_members[j].nickname && this.itemList[i].group_members[j].nickname.indexOf(this.queryValue) >= 0) || (this.itemList[i].group_members[j].login_name && this.itemList[i].group_members[j].login_name.indexOf(this.queryValue) >= 0)) {
                                    tmpGroups.group_members.push(this.itemList[i].group_members[j]);
                                }
                            }
                            if (tmpGroups.group_members.length) {
                                this.items.push(tmpGroups);
                            }
                        }
                    }
                } else {
                    this.items = this.itemList;
                }
            }
        },

        watch: {
            queryValue:function (val,oldVal) {
                this.search();
            }
        }
    });
};
